/*
 * Process resource limits
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file "COPYING" in the main directory of this archive
 * for more details.
 *
 * Copyright (C) 1995 by Ralf Baechle
 */
#ifndef __ASM_MIPS_RESOURCE_H
#define __ASM_MIPS_RESOURCE_H

/*
 * Resource limits
 *
 * Changed this into an enum for Linux 1.3.48 so that it can better be
 * used for the GNU libc.  The enums are the preferable way to do it, but
 * we need to keep the #defines so that old software can check for presence
 * of preprocessor symbols.
 */
enum __rlimit_resource
{
#define RLIMIT_CPU RLIMIT_CPU		/* CPU time in ms */
	RLIMIT_CPU,
#define RLIMIT_FSIZE RLIMIT_FSIZE	/* Maximum filesize */
	RLIMIT_FSIZE,
#define RLIMIT_DATA RLIMIT_DATA		/* max data size */
	RLIMIT_DATA,
#define RLIMIT_STACK RLIMIT_STACK	/* max stack size */
	RLIMIT_STACK,
#define RLIMIT_CORE RLIMIT_CORE		/* max core file size */
	RLIMIT_CORE,
#define RLIMIT_NOFILE RLIMIT_NOFILE	/* max number of open files */
	RLIMIT_NOFILE,
#define RLIMIT_OFILE RLIMIT_OFILE	/* Another name for the same thing.  */
	RLIMIT_OFILE = RLIMIT_NOFILE,
#define RLIMIT_VMEM RLIMIT_VMEM		/* mapped memory */
	RLIMIT_VMEM,
#define RLIMIT_AS RLIMIT_AS		/* Another name for the same thing.  */
	RLIMIT_AS = RLIMIT_VMEM,
#define RLIMIT_RSS RLIMIT_RSS		/* max resident set size */
	RLIMIT_RSS,
#define RLIMIT_NPROC RLIMIT_NPROC	/* max number of processes */
	RLIMIT_NPROC,
#define RLIMIT_MEMLOCK RLIMIT_MEMLOCK	/* max locked-in-memory address space*/
	RLIMIT_MEMLOCK,
#define RLIMIT_NLIMITS RLIMIT_NLIMITS	/* Number of limit flavors.  */
	RLIMIT_NLIMITS,
#define RLIM_NLIMITS RLIM_NLIMITS	/* Traditional name for same.  */
	RLIM_NLIMITS = RLIMIT_NLIMITS
};

#ifdef __KERNEL__

#define INIT_RLIMITS					\
{							\
	{LONG_MAX, LONG_MAX},				\
	{LONG_MAX, LONG_MAX},				\
	{LONG_MAX, LONG_MAX},				\
	{_STK_LIM, _STK_LIM},				\
	{       0, LONG_MAX},				\
	{NR_OPEN, NR_OPEN},				\
	{LONG_MAX, LONG_MAX},				\
	{LONG_MAX, LONG_MAX},				\
	{MAX_TASKS_PER_USER, MAX_TASKS_PER_USER},	\
	{ LONG_MAX, LONG_MAX },				\
}

#endif /* __KERNEL__ */

#endif /* __ASM_MIPS_RESOURCE_H */
